@@ -1,6 +1,6 @@
 /*
     GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2002, 2005  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 2002, 2005, 2018  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
 
@@ -15,8 +15,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef GNU_Gama_GaMa_XML_DataParser_data_parser_dataparser_h_
@@ -63,9 +62,6 @@ namespace GNU_gama {
           return (this->*etag[state])(name);
         }
 
-      static const char* const xml_start;
-      static const char* const xml_end;
-
     private:
 
       std::list<DataObject::Base*>& objects;
